@@ -1,5 +1,6 @@
 /*
  *   SPDX-FileCopyrightText: 2011 Matthias Fuchs <mat69@gmx.net>
+ *   SPDX-FileCopyrightText: 2022 Alexander Lohnau <alexander.lohnau@gmx.de>
  *
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -7,7 +8,7 @@
 #ifndef CHECK_NEW_STRIPS_H
 #define CHECK_NEW_STRIPS_H
 
-#include <Plasma/DataEngine>
+#include "engine/comic.h"
 
 /**
  * This class searches for the newest comic strips of predefined comics in a defined interval.
@@ -18,7 +19,7 @@ class CheckNewStrips : public QObject
     Q_OBJECT
 
 public:
-    CheckNewStrips(const QStringList &identifiers, Plasma::DataEngine *engine, int minutes, QObject *parent = nullptr);
+    CheckNewStrips(const QStringList &identifiers, ComicEngine *engine, int minutes, QObject *parent = nullptr);
 
 Q_SIGNALS:
     /**
@@ -29,16 +30,14 @@ Q_SIGNALS:
      */
     void lastStrip(int index, const QString &identifier, const QString &suffix);
 
-public Q_SLOTS:
-    void dataUpdated(const QString &name, const Plasma::DataEngine::Data &data);
-
 private Q_SLOTS:
     void start();
 
 private:
+    void dataUpdated(const ComicMetaData &data);
     int mMinutes;
     int mIndex;
-    Plasma::DataEngine *mEngine;
+    ComicEngine *mEngine;
     const QStringList mIdentifiers;
 };
 
